%define anolis_release 1

%global lib_version 2308.0.0

Name:           abseil-cpp
Version:        20230802.1
Release:        %{anolis_release}%{?dist}
Summary:        C++ Common Libraries

License:        Apache-2.0 AND LicenseRef-Fedora-Public-Domain
URL:            https://abseil.io
Source0:        https://github.com/abseil/abseil-cpp/archive/%{version}/%{name}-%{version}.tar.gz

BuildRequires:  cmake ninja-build gcc-c++
BuildRequires:  gmock-devel gtest-devel

Provides:       bundled(cctz)

%description
Abseil is an open-source collection of C++ library code designed to augment
the C++ standard library. The Abseil library code is collected from
Google's own C++ code base, has been extensively tested and used in
production, and is the same code we depend on in our daily coding lives.

In some cases, Abseil provides pieces missing from the C++ standard; in
others, Abseil provides alternatives to the standard for special needs we've
found through usage in the Google code base. We denote those cases clearly
within the library code we provide you.

Abseil is not meant to be a competitor to the standard library; we've just
found that many of these utilities serve a purpose within our code base,
and we now want to provide those resources to the C++ community as a whole.

%package testing
Summary:        Libraries needed for running tests on the installed %{name}
Requires:       %{name} = %{version}-%{release}
Provides:       bundled(cctz)

%description testing
%{summary}.

%package devel
Summary: Development files for %{name}
Requires: %{name} = %{version}-%{release}
Requires: %{name}-testing = %{version}-%{release}
Provides: bundled(cctz)

%description devel
Development headers for %{name}

%package doc
Summary:  Doc files for %{name}
Requires: %{name} = %{version}-%{release}
BuildArch:noarch

%description doc
Doc files for %{name}

%prep
%autosetup -p1 -S gendiff

%build
%cmake \
  -GNinja \
  -DABSL_USE_EXTERNAL_GOOGLETEST:BOOL=ON \
  -DABSL_FIND_GOOGLETEST:BOOL=ON \
  -DABSL_ENABLE_INSTALL:BOOL=ON \
  -DABSL_BUILD_TESTING:BOOL=ON \
  -DABSL_BUILD_TEST_HELPERS:BOOL=ON \
  -DCMAKE_BUILD_TYPE:STRING=None \
  -DCMAKE_CXX_STANDARD:STRING=17
%cmake_build


%install
%cmake_install
%generate_compatibility_deps

%check
%ctest

%files
%license LICENSE
%{_libdir}/libabsl_*.so.%{lib_version}
%dir %{abidir}
%{abidir}/*.dump

%files testing
%{_libdir}/libabsl_exception_safety_testing.so.%{lib_version}
%{_libdir}/libabsl_atomic_hook_test_helper.so.%{lib_version}
%{_libdir}/libabsl_spinlock_test_common.so.%{lib_version}
%{_libdir}/libabsl_test_instance_tracker.so.%{lib_version}
%{_libdir}/libabsl_hash_generator_testing.so.%{lib_version}
%{_libdir}/libabsl_stack_consumption.so.%{lib_version}
%{_libdir}/libabsl_log_internal_test_actions.so.%{lib_version}
%{_libdir}/libabsl_log_internal_test_helpers.so.%{lib_version}
%{_libdir}/libabsl_log_internal_test_matchers.so.%{lib_version}
%{_libdir}/libabsl_scoped_mock_log.so.%{lib_version}
%{_libdir}/libabsl_pow10_helper.so.%{lib_version}
%{_libdir}/libabsl_per_thread_sem_test_common.so.%{lib_version}
%{_libdir}/libabsl_time_internal_test_util.so.%{lib_version}

%files devel
%{_includedir}/absl
%{_libdir}/libabsl_*.so
%{_libdir}/cmake/absl
%{_libdir}/pkgconfig/absl_*.pc

%files doc
%doc FAQ.md README.md UPGRADES.md

%changelog
* Fri Sep 06 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 20230802.1-1
- update to 20230802.1 for protobuf

* Wed Jan  3 2024 Wenlong Zhang <zhangwenlong@loongson.cn> - 20230125.3-2
- rebuild for loongarch64

* Fri May 05 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 20230125.3-1
- init from upstream
